@@ -1,6 +1,7 @@
-from logilab.common.testlib import unittest_main
+import unittest
 from cubicweb.devtools.testlib import AutomaticWebTest
 
+
 class AddressbookAutomaticWebTest(AutomaticWebTest):
 
     def to_test_etypes(self):
@@ -9,7 +10,8 @@ class AddressbookAutomaticWebTest(AutomaticWebTest):
     def list_startup_views(self):
         return ()
 
+
 del AutomaticWebTest
 
 if __name__ == '__main__':
-    unittest_main()
+    unittest.main()
